@@ -1,4 +1,6 @@
 package OverloadSubClass;
+use warnings;
+use strict;
 use base 'OverloadBaseClass';
 
 sub local_method {
